Struct avalanche_ops::aws::spec::Resource
source · pub struct Resource {
pub identity: Option<Identity>,
pub regions: Vec<String>,
pub s3_bucket: String,
pub ingress_ipv4_cidr: String,
pub regional_resources: BTreeMap<String, RegionalResource>,
pub created_nodes: Option<Vec<Node>>,
}Expand description
Represents the current AWS resource configurations and states. These states are necessary for resource cleanups.
Fields
identity: Option<Identity>AWS STS caller loaded from its local environment. READ ONLY.
regions: Vec<String>AWS region to create resources. MUST BE NON-EMPTY.
s3_bucket: StringName of the bucket to store (or download from)
the configuration and resources (e.g., S3).
If not exists, it creates automatically.
If exists, it skips creation and uses the existing one.
MUST BE NON-EMPTY.
ALWAYS USE THE FIRST REGION IN regions for S3.
AND SHARED ACROSS MULTIPLE REGIONS.
ingress_ipv4_cidr: Stringregional_resources: BTreeMap<String, RegionalResource>Only populate as many as we need to fill up anchor/non-anchor nodes. e.g., “regions” may have 5 but we may only need 2 regions for 3 node cluster.
created_nodes: Option<Vec<Node>>Created nodes at the start of the network. May become stale.
Implementations